#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Makefile - System Security Script build and packaging script
#

use ExtUtils::MakeMaker;
use Config;
use strict;

WriteMakefile(
	NAME			=> 'Security',
	DISTNAME		=> 'security',
	AUTHOR		=> 'Jim Pirzyk <jim+security@pirzyk.org>',
	PERM_RWX		=> 700,
	PERM_RW		=> 600,
	PMLIBDIRS		=> [ 'lib' ],
	MAN1PODS		=> { 'sbin/security.pl' => '$(INST_MAN1DIR)/security.$(MAN1EXT)' },
	VERSION_FROM	=> 'sbin/security.pl',
	PREREQ_PM		=> {
		     'Net::SMTP' => 0,
     		'Digest::SHA1' => 2.00,
     		'Sys::Filesystem' => 1.22,
     		'Fcntl' => 0,
     		'DB_File' => 0,

			# Needed for 'make test'
     		'List::Compare' => 0,
     		'Unix::Mknod' => 0,
	},
	macro 		=> {
		($] <= 5.008 ? (
			'ECHO'		=> 'echo',
			'SITEPREFIX'	=> '$(PREFIX)',
		) : ())
	}
);

sub MY::postamble
{
	my ($preamble, $os, $install, $body, @installfiles, $package, $id);

	$id = 'id';

	# the stock id command on Solaris does not support the -u option.
	if ($^O eq 'solaris' ) {
		if ( -f '/usr/xpg4/bin/id' ) {
			$id = '/usr/xpg4/bin/id';
		} else {
			# Since it is not installed, then hope and pray we get
			# id somewhere else (not /usr/bin).
			warn "Please install SUNWxcu4 (for /usr/xpg4/bin/id)\n";
		}
	}

	$package = '
package:: ';

	$preamble = "
ID			= $id
ETC_DIR		= /etc
VAR_DB_DIR	= /var/db

";

	if ($] == 5.006001) {
		$preamble .= 'all :: Makefile.patched

Makefile.patched:
	patch -p0 < perl-5.6.1-Makefile-destdir.patch
	touch Makefile.patched

clean::
	$(RM_F) Makefile.patched

'
	}

	if ($] == 5.008) {
		$preamble .= 'all :: Makefile.patched

Makefile.patched:
	patch -p0 < perl-5.8.0-Makefile-destdir.patch
	touch Makefile.patched

clean::
	$(RM_F) Makefile.patched

'
	}
	
	@installfiles = q{ $(DESTDIR)$(SITEPREFIX)/sbin/security $(DESTDIR)$(SITEPREFIX)$(ETC_DIR)/security/security.cf $(DESTDIR)$(SITEPREFIX)$(VAR_DB_DIR)/security/checksum.db };

	$body = '

$(DESTDIR)$(SITEPREFIX)/sbin:
	$(MKPATH) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi

$(DESTDIR)$(SITEPREFIX)$(ETC_DIR)/security:
	$(MKPATH) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi

$(DESTDIR)$(SITEPREFIX)$(VAR_DB_DIR)/security:
	$(MKPATH) $@
	$(CHMOD) $(PERM_RWX) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi

$(DESTDIR)$(SITEPREFIX)/sbin/security: $(DESTDIR)$(SITEPREFIX)/sbin sbin/security.pl
	$(PERL) -pi -e \'s|##SITEPREFIX##|$(SITEPREFIX)|\' < sbin/security.pl > $@
	$(CHMOD) $(PERM_RWX) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi

$(DESTDIR)$(SITEPREFIX)$(VAR_DB_DIR)/security/checksum.db: $(DESTDIR)$(SITEPREFIX)$(VAR_DB_DIR)/security
	$(PERL) -e "use DB_File; tie %h, \'DB_File\', \'$@\', O_CREAT|O_RDWR, 0$(PERM_RW), $$DB_HASH;"
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi
	@if [ ! -s $@ ]; then $(RM_F) $@; echo "Error in creating checksum.db, DB_File broken in this perl install"; exit 1; fi

$(DESTDIR)$(SITEPREFIX)$(ETC_DIR)/security/security.cf: sbin/generate_config.pl $(DESTDIR)$(SITEPREFIX)$(ETC_DIR)/security
	$(PERL) -I blib/lib sbin/generate_config.pl $(INSTALL_OPTS) -M $(INSTALLSITELIB) -P $(SITEPREFIX) -R $(DESTDIR) > $@
	$(CHMOD) 0400 $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi
';

	if ($Config{'osname'} eq 'freebsd' ) {
		push @installfiles,  q{ $(DESTDIR)$(ETC_DIR)/daily.local };
		$package .= 'ports/distinfo 

$(DESTDIR)$(ETC_DIR)/daily.local:
	$(ECHO) \'$(SITEPREFIX)/sbin/security $(DEV_NULL)\' > $@
	$(CHMOD) $(PERM_RWX) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi

ports/distinfo:
	cd ports \
	 $(MAKE) makesum

clean::
	$(RM_F) ports/distinfo
';
	}

	# Since Solaris only supports two ARCHes, we link the two files.
	if ($Config{'osname'} eq 'solaris' ) {
		my $osver = $Config{'osvers'};
		$osver =~ s/2\.//;

		$package .= 'install $(DESTDIR)/prototype $(DESTDIR)/pkginfo $(DESTDIR)/depend pkgdir
	pkgmk -o -r $(DESTDIR) -f $(DESTDIR)/prototype -d pkgdir 
	pkgtrans -o -s pkgdir ../$(DISTVNAME)-sol' .  $osver . '-sparc-local $(DISTNAME)
	ln -f $(DISTVNAME)-sol' . $osver . '-sparc-local $(DISTVNAME)-sol' . $osver . '-i386-local
	$(RM_RF) pkgdir

pkgdir:
	$(MKPATH) $@

# TODO: Generate the file on the fly.
$(DESTDIR)/pkginfo: pkginfo
	$(PERL) -pi -e \'s/^VERSION=.*$$/VERSION=$(VERSION)/\' < pkginfo > $@

$(DESTDIR)/depend: depend.sol' . $osver . '
	$(CP) depend.sol' . $osver . ' $@

$(DESTDIR)/prototype: 
	$(ECHO) "i pkginfo=./pkginfo" > $@
	$(ECHO) "i depend=./depend" >> $@
	( cd $(DESTDIR); find . -print | egrep -v \'depend|pkginfo|prototype\' | pkgproto | $(PERL) -pi -e \'s/ [^ ]* [^ ]*$$/ root root\n/g\' >> $@ )

clean::
	$(RM_RF) pkgdir
';
	}

	if ($Config{'osname'} eq 'linux' ) {
		$package .= 'dist
	rpmbuild -tb --quiet $(DISTVNAME).tar$(SUFFIX)

';
		push @installfiles,  q{ $(DESTDIR)$(ETC_DIR)/cron.daily/security };

		$body .= '

$(DESTDIR)/etc/cron.daily:
	$(MKPATH) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi

$(DESTDIR)$(ETC_DIR)/cron.daily/security: $(DESTDIR)$(ETC_DIR)/cron.daily
	$(ECHO) \'$(SITEPREFIX)/sbin/security $(DEV_NULL)\' > $@
	$(CHMOD) $(PERM_RWX) $@
	if [ `$(ID) -u` -eq 0 ]; then chown 0:0 $@; fi
';
	}

	$install = 'install :: ' . join (' ', @installfiles);

	return $preamble . $os . $install . $body . $package;
}
