#!/usr/bin/env perl
#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  03.t - Test the utility modules.
#

use Test;
use strict;

plan tests => 11;

our ($format, %opts);
#$opts{'M'} = '-';
#$opts{'d'} = 1;

use Security::util::SHA1;
&Security::util::SHA1::init();
my $expected = "SHA1(/dev/null) = da39a3ee5e6b4b0d3255bfef95601890afd80709\n";
my $result = &Security::util::SHA1::check('/dev/null');

ok ($result, $expected, "SHA1 Checksum error on /dev/null");

use Security::util::uniq;
use List::Compare;
my (@expected) = ( 1, 2, 3, 4, 5, 6 );
my (@res) = &Security::util::uniq::uniq(( 1, 2, 3, 4, 1, 5, 6 ));
my $lc = List::Compare->new(\@res, \@expected);

ok (scalar $lc->get_unique(), 0, "Error in uniq() routine");

use Security::util::stat;

my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
  $atime,$mtime,$ctime,$blksize,$blocks) = &Security::util::stat::get_stat('/dev/null', 'stat');

ok ($uid, 0, "/dev/null owner not correct");
ok ($gid,
	$^O eq 'solaris' ? 3: 0,
	"/dev/null group not correct");
ok ($nlink, 1, "/dev/null number of links is not correct");
ok ($mode, 8630, "/dev/null mode should be rw-rw-rw-");
ok ($size, 0, "/dev/null size should be 0");

use Security::util::users;
&Security::util::users::init();

ok (&Security::util::users::get('name', 'root', 'uid'), 0, "root did not have correct uid");
ok (&Security::util::users::get('uid', 0, 'name'),
	$^O eq 'freebsd' ? 'toor': 'root',
	"uid 0 not correct name");

use Security::util::groups;
&Security::util::groups::init();
ok (&Security::util::groups::get('name',
		$^O eq 'darwin' || $^O eq 'freebsd' ? 'wheel': 'root',
		'gid'),
	0,
	"root/wheel did not have correct gid");
ok (&Security::util::groups::get('gid', 0, 'name'),
	$^O eq 'darwin' || $^O eq 'freebsd' ? 'wheel': 'root',
	"gid 0 not correct name");

exit 0;
