#!/usr/bin/env perl
#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  07.t - mail config file testing.
#

use Test;
use strict;

plan tests => 7;

use Security::util::users;
use Security::mail;

our (%opts);
#$opts{'d'} = 1;

# Use this test script as an intruder file test.
our @mailfiles = (
	'security_test.' . $$,
	'security_test.' . $$ . '.2',
	'security_test.' . $$ . '.3',
);
my @FILES;

sub read_config {}
sub print_data {}

sub create_file {
	my ($file, $uid, $gid, $mode) = @_;
	my ($FP);

	if ( ! -f $file ) { 
		open ($FP, "> $file") || die "Could not create test file ($file)\n";
		close $FP;
		if ( $< eq 0 ) {
			chown $uid, $gid, $file || die "Could not chown file ($file)\n";
		} else {
			chown -1, $gid, $file || die "Could not chgrp file ($file)\n";
		}
		chmod $mode, $file if ( defined $mode );
		push @FILES, $file;
	} else {
		die "Could not create test file ($file), already exists\n";
	}
}

&Security::util::users::init();
&Security::mail::init();

# Create files we should complain about
&create_file("$ENV{'HOME'}/$mailfiles[0]", $<, $(, 0666);		# Complain about file other modes
&create_file("$ENV{'HOME'}/$mailfiles[1]", $<+1, -1, 0600);		# Complain about file ownership
&create_file("$ENV{'HOME'}/$mailfiles[2]", -1, -1, 0660);		# Complain about file group modes

&Security::mail::check();

ok ( scalar keys %Security::mail::mailworld, 1, "Found not right number of world writable mail files");
skip (
	($< != 0? "Test needs to be run as root": 0),
	scalar keys %Security::mail::mailowner>1, 1,
);
ok ( scalar keys %Security::mail::mailgroup, 2, "Found not right number of group writable mail files");

ok ( exists $Security::mail::mailworld{"$ENV{'HOME'}/$mailfiles[0]"}, 1, "Expected to find world writable mail file");
skip (
	($< != 0? "Test needs to be run as root": 0),
	exists $Security::mail::mailowner{"$ENV{'HOME'}/$mailfiles[1]"},
);
ok ( exists $Security::mail::mailgroup{"$ENV{'HOME'}/$mailfiles[0]"}, 1, "Expected to find group writable mail file");
ok ( exists $Security::mail::mailgroup{"$ENV{'HOME'}/$mailfiles[2]"}, 1, "Expected to find group writable mail file");

unlink(@FILES);

exit 0;
